@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2019-08-20'; # DATE
-our $VERSION = '0.330'; # VERSION
+our $DATE = '2019-12-18'; # DATE
+our $VERSION = '0.331'; # VERSION
 
 use 5.010001;
 use strict;
@@ -525,6 +525,10 @@ Known options:
 
   which is quite helpful.
 
+* workaround_with_wordbreaks
+
+  Boolean. Default is true. See source code for more details.
+
 _
 
         },
@@ -602,7 +606,10 @@ sub format_completion {
     # case-insensitive matching, although this does not have the ability to
     # replace the current word (e.g. if we type 'text::an' then bash can only
     # replace the current word 'an' with 'ANSI).
-    if (defined($opts->{word})) {
+    {
+        last unless $opts->{workaround_with_wordbreaks} // 1;
+        last unless defined $opts->{word};
+
         if ($opts->{word} =~ s/(.+[\@><=;|&\(:])//) {
             my $prefix = $1;
             for (@$words) {
@@ -755,7 +762,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.330 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-08-20.
+This document describes version 0.331 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-12-18.
 
 =head1 DESCRIPTION
 
@@ -924,6 +931,10 @@ But when summaries are shown, user will see:
 
 which is quite helpful.
 
+=item * workaround_with_wordbreaks
+
+Boolean. Default is true. See source code for more details.
+
 =back
 
 =back
